@@ -3,9 +3,9 @@ package Sah::Schema::str_or_code;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-10-23'; # DATE
+our $DATE = '2023-12-20'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 our $schema = [any => {
     summary => 'String or coderef (if string is of the form `sub {...}`)',
@@ -24,6 +24,13 @@ warnings`.
 This schema is handy if you want to accept string or coderef from the
 command-line.
 
+What's the difference between this schema and `code_from_str` (from
+<pm:Sah::Schemas::Code>)? Both this schema and `code_from_str` accept string,
+but `code_from_str` will directly compile any input string while this schema
+will only convert string to code if it is in the form of `sub { ... }`. In other
+words, this schema can output either string or coderef, while `code_from_str`
+will always produce coderef.
+
 MARKDOWN
     of => [
         ['str'],
@@ -61,7 +68,7 @@ Sah::Schema::str_or_code - String or coderef (if string is of the form `sub {...
 
 =head1 VERSION
 
-This document describes version 0.016 of Sah::Schema::str_or_code (from Perl distribution Sah-Schemas-Str), released on 2023-10-23.
+This document describes version 0.017 of Sah::Schema::str_or_code (from Perl distribution Sah-Schemas-Str), released on 2023-12-20.
 
 =head1 SYNOPSIS
 
@@ -97,12 +104,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "sub{\"foo\"}";
+ $data = "";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
  $data = "sub {1=2}";
- my $errmsg = $validator->($data); # => "Error in compiling code: Can't modify constant item in scalar assignment at (eval 2804) line 1, at EOF\n"
+ my $errmsg = $validator->($data); # => "Error in compiling code: Can't modify constant item in scalar assignment at (eval 2747) line 1, at EOF\n"
 
 Often a schema has coercion rule or default value rules, so after validation the
 validated value will be different from the original. To return the validated
@@ -112,12 +119,12 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "sub{\"foo\"}";
- my $res = $validator->($data); # => ["",sub{BEGIN {${^WARNING_BITS} = "\x55\x55\x55\x55\x55\x55\x55\x55\x55\x55\x55\x51\x55\x55\x55\x55\x55\x55\x55\x55\x55\x55\x55"}use strict;no feature;use feature ':5.10';'foo'}]
+ $data = "";
+ my $res = $validator->($data); # => ["",""]
  
  # a sample invalid data
  $data = "sub {1=2}";
- my $res = $validator->($data); # => ["Error in compiling code: Can't modify constant item in scalar assignment at (eval 2818) line 1, at EOF\n","sub {1=2}"]
+ my $res = $validator->($data); # => ["Error in compiling code: Can't modify constant item in scalar assignment at (eval 2760) line 1, at EOF\n","sub {1=2}"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -225,6 +232,13 @@ warnings>.
 This schema is handy if you want to accept string or coderef from the
 command-line.
 
+What's the difference between this schema and C<code_from_str> (from
+L<Sah::Schemas::Code>)? Both this schema and C<code_from_str> accept string,
+but C<code_from_str> will directly compile any input string while this schema
+will only convert string to code if it is in the form of C<sub { ... }>. In other
+words, this schema can output either string or coderef, while C<code_from_str>
+will always produce coderef.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Str>.
