@@ -3,9 +3,9 @@ package Sah::Schema::str_or_re_or_code;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-10-23'; # DATE
+our $DATE = '2023-12-20'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 our $schema = [any => {
     summary => 'String, or regex (if string is of the form `/.../`), or coderef (if string is in the form of `sub { ... }`)',
@@ -84,7 +84,7 @@ Sah::Schema::str_or_re_or_code - String, or regex (if string is of the form `/..
 
 =head1 VERSION
 
-This document describes version 0.016 of Sah::Schema::str_or_re_or_code (from Perl distribution Sah-Schemas-Str), released on 2023-10-23.
+This document describes version 0.017 of Sah::Schema::str_or_re_or_code (from Perl distribution Sah-Schemas-Str), released on 2023-12-20.
 
 =head1 SYNOPSIS
 
@@ -140,12 +140,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "sub{\"foo\"}";
+ $data = "";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = {};
- my $errmsg = $validator->($data); # => "Not of type text"
+ $data = "/foo[/";
+ my $errmsg = $validator->($data); # => "Invalid regex: Unmatched [ in regex; marked by <-- HERE in m/foo[ <-- HERE / at (eval 2818) line 1.\n"
 
 Often a schema has coercion rule or default value rules, so after validation the
 validated value will be different from the original. To return the validated
@@ -155,12 +155,12 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "sub{\"foo\"}";
- my $res = $validator->($data); # => ["",sub{BEGIN {${^WARNING_BITS} = "\x55\x55\x55\x55\x55\x55\x55\x55\x55\x55\x55\x51\x55\x55\x55\x55\x55\x55\x55\x55\x55\x55\x55"}use strict;no feature;use feature ':5.10';'foo'}]
+ $data = "";
+ my $res = $validator->($data); # => ["",""]
  
  # a sample invalid data
- $data = {};
- my $res = $validator->($data); # => ["Not of type text",{}]
+ $data = "/foo[/";
+ my $res = $validator->($data); # => ["Invalid regex: Unmatched [ in regex; marked by <-- HERE in m/foo[ <-- HERE / at (eval 2834) line 1.\n","/foo[/"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
