@@ -4,9 +4,9 @@ use 5.014;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-10-23'; # DATE
+our $DATE = '2023-12-20'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 1;
 # ABSTRACT: Various string schemas
@@ -23,7 +23,7 @@ Sah::Schemas::Str - Various string schemas
 
 =head1 VERSION
 
-This document describes version 0.016 of Sah::Schemas::Str (from Perl distribution Sah-Schemas-Str), released on 2023-10-23.
+This document describes version 0.017 of Sah::Schemas::Str (from Perl distribution Sah-Schemas-Str), released on 2023-12-20.
 
 =head1 SAH SCHEMAS
 
@@ -121,6 +121,13 @@ warnings>.
 This schema is handy if you want to accept string or coderef from the
 command-line.
 
+What's the difference between this schema and C<code_from_str> (from
+L<Sah::Schemas::Code>)? Both this schema and C<code_from_str> accept string,
+but C<code_from_str> will directly compile any input string while this schema
+will only convert string to code if it is in the form of C<sub { ... }>. In other
+words, this schema can output either string or coderef, while C<code_from_str>
+will always produce coderef.
+
 
 =item * L<str_or_re|Sah::Schema::str_or_re>
 
@@ -137,6 +144,13 @@ and C<)> are allowed as the delimiter.
 
 Currently modifiers C<i>, C<m>, and C<s> after the second C</> are allowed.
 
+What's the difference between this schema and C<re_from_str> (from
+L<Sah::Schemas::Re>)? Both this schema and C<re_from_str> accept string, but
+this schema will leave strings not in the form of C</.../> or C<qr(...)> as-is,
+while C<re_from_str> will still convert the string to Regexp object (after
+escaping the special characters). In other words, this schema can produce
+strings while C<str_or_re> always produces Regexp object.
+
 
 =item * L<str_or_re_or_code|Sah::Schema::str_or_re_or_code>
 
